# Methods


## Offline

```{toctree}
:maxdepth: 1

methods/chisquaredrift.ipynb
methods/ksdrift.ipynb
methods/cvmdrift.ipynb
methods/fetdrift.ipynb
methods/mmddrift.ipynb
methods/lsdddrift.ipynb
methods/learnedkerneldrift.ipynb
methods/classifierdrift.ipynb
methods/spotthediffdrift.ipynb
methods/modeluncdrift.ipynb
methods/tabulardrift.ipynb
methods/contextmmddrift.ipynb
```

## Online
```{toctree}
:maxdepth: 1

methods/onlinemmddrift.ipynb
methods/onlinelsdddrift.ipynb
methods/onlinecvmdrift.ipynb
methods/onlinefetdrift.ipynb
```
